# Collepedia

A dedicated client to fetch and manage posts from Collepedia.

This library provides a clean, robust, and easy-to-use interface to retrieve, filter, and manage post data.

## Features

-   **Dedicated Client**: Hardcoded for the Collepedia feed for simplicity and reliability.
-   **Advanced Fetching**: Fetch posts with pagination and server-side category filtering.
-   **Powerful Filtering**: Perform complex queries on cached data by author, category, or date range.
-   **Robust Error Handling**: Custom exceptions for network and parsing errors.
-   **Cache Persistence**: Save fetched data to a JSON file and load it back later.

## What's New
-   **No Date**: This was an error with the first version of the Library
-   **Posts Fetch Error**: An error originated in version 1.0.1 of this library where all articles wasn't fetched

## Projects
-   **[ColleSearch](https://collesearch.vercel.app/)**: A Search Engine for Collepedia contents that searches across all the website programmically through python with this library.

## More Informations

If you need the full documentation and all examples, uses and more aboyt the library please head up to [Collepedia Python Package](https://github.com/AbdulRahman-Muhammad/collepediapy) in GitHub.

## Installation

```bash
pip install collepedia
```
